@@ -1,5 +1,5 @@
-from RFEM.initModel import Model, clearAtributes, ConvertToDlString
-from RFEM.enums import LineType, LineArcAlphaAdjustmentTarget
+from RFEM.initModel import Model, clearAtributes, ConvertToDlString, ConvertStrToListOfInt
+from RFEM.enums import LineType, LineArcAlphaAdjustmentTarget, ObjectTypes
 
 class Line():
     def __init__(self,
@@ -460,3 +460,15 @@ class Line():
 
         # Add Line to client model
         model.clientModel.service.set_line(clientObject)
+
+    @staticmethod
+    def DeleteLine(lines_no: str = '1 2', model = Model):
+
+        '''
+        Args:
+            lines_no (str): Numbers of Lines to be deleted
+        '''
+
+        # Delete from client model
+        for line in ConvertStrToListOfInt(lines_no):
+            model.clientModel.service.delete_object(ObjectTypes.E_OBJECT_TYPE_LINE.name, line)
\ No newline at end of file
