@@ -1,5 +1,5 @@
-from RFEM.initModel import Model, clearAtributes, ConvertToDlString
-from RFEM.enums import SolidType
+from RFEM.initModel import Model, clearAtributes, ConvertToDlString, ConvertStrToListOfInt
+from RFEM.enums import SolidType, ObjectTypes
 
 class Solid():
     def __init__(self,
@@ -13,7 +13,7 @@ class Solid():
         '''
         Args:
             no (int): Solid Tag
-            boundary_surfaces_no (str): Tags of Surfaces defining Solid
+            boundary_surfaces_no (str): Numbers of Surfaces defining Solid
             material_no (int): Tag of Material assigned to Solid
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
@@ -57,7 +57,7 @@ class Solid():
         '''
         Args:
             no (int): Solid Tag
-            boundary_surfaces_no (str): Tags of Surfaces defining Solid
+            boundary_surfaces_no (str): Numbers of Surfaces defining Solid
             material_no (int): Tag of Material assigned to Solid
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
@@ -104,7 +104,7 @@ class Solid():
         '''
         Args:
             no (int): Solid Tag
-            boundary_surfaces_no (str): Tags of Surfaces defining Gas
+            boundary_surfaces_no (str): Numbers of Surfaces defining Gas
             material_no (int): Tag of Material assigned to Solid
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
@@ -151,7 +151,7 @@ class Solid():
         '''
         Args:
             no (int): Solid Tag
-            boundary_surfaces_no (str): Tags of Surfaces defining Contact
+            boundary_surfaces_no (str): Numbers of Surfaces defining Contact
             material_no (int): Tag of Material assigned to Solid
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
@@ -198,7 +198,7 @@ class Solid():
         '''
         Args:
             no (int): Solid Tag
-            boundary_surfaces_no (str): Tags of Surfaces defining Soil
+            boundary_surfaces_no (str): Numbers of Surfaces defining Soil
             material_no (int): Tag of Material assigned to Solid
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
@@ -231,4 +231,16 @@ class Solid():
                 clientObject[key] = params[key]
 
         # Add Surface to client model
-        model.clientModel.service.set_solid(clientObject)
\ No newline at end of file
+        model.clientModel.service.set_solid(clientObject)
+
+    @staticmethod
+    def DeleteSolid(solids_no: str = '1 2', model = Model):
+
+        '''
+        Args:
+            solids_no (str): Numbers of Solids to be deleted
+        '''
+
+        # Delete solids from client model
+        for solid in ConvertStrToListOfInt(solids_no):
+            model.clientModel.service.delete_object(ObjectTypes.E_OBJECT_TYPE_SOLID.name, solid)
\ No newline at end of file
