@@ -1,8 +1,8 @@
-from RFEM.enums import ThicknessDirection, ThicknessType
-from RFEM.enums import ThicknessOrthotropyType, AddOn
+from RFEM.enums import ThicknessDirection, ThicknessType, LayerType
+from RFEM.enums import ThicknessOrthotropyType, AddOn, ObjectTypes
 from RFEM.enums import ThicknessShapeOrthotropySelfWeightDefinitionType
 from RFEM.enums import ThicknessStiffnessMatrixSelfWeightDefinitionType
-from RFEM.initModel import Model, GetAddonStatus, clearAtributes, SetAddonStatus
+from RFEM.initModel import Model, GetAddonStatus, clearAtributes, SetAddonStatus, ConvertStrToListOfInt
 from math import pi
 
 class Thickness():
@@ -372,7 +372,7 @@ class Thickness():
     def Layers(
                  no: int = 1,
                  name: str = None,
-                 layers = [[0, 1, 0.2, 0.0, '']],
+                 layers = [[[0, 1, 0.012], [0, 1, 0.01]]],
                  comment: str = '',
                  params: dict = None,
                  model = Model):
@@ -385,7 +385,6 @@ class Thickness():
             name (str): Thickness Name
             material_no (int): Tag of Material assigned to Thickness
             properties (list): Nested List of Layer Properties
-                properties: [[thickness_type, material, thickness, rotation, comment], ...]
             comment (str, optional): Comments
             params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
@@ -412,21 +411,24 @@ class Thickness():
         clientObject.type = ThicknessType.TYPE_LAYERS.name
 
         # Layers
-        clientObject.layers_reference_table = model.clientModel.factory.create('ns0:thickness.layers_reference_table')
+        clientObject.layers_reference_table = model.clientModel.factory.create('ns0:array_of_thickness_layers_reference_table')
 
         for i,j in enumerate(layers):
-            tlrt = model.clientModel.factory.create('ns0:thickness_layers_reference_table')
-            tlrt.no = no
-            tlrt.layer_no = i+1
-            tlrt.layer_type = None
-            tlrt.thickness_type = layers[i][0]
-            tlrt.material = layers[i][1]
-            tlrt.thickness = layers[i][2]
-            tlrt.angle = layers[i][3] * (pi/180)
-            tlrt.connection_with_other_topological_elements = False
-            tlrt.comment = layers[i][4]
-            tlrt.specific_weight = 0
-            tlrt.weight = 0
+            tlrt = model.clientModel.factory.create('ns0:thickness_layers_reference_table_row')
+            tlrt.no = i+1
+            tlrt.row.layer_no = i+1
+            tlrt.row.layer_type = LayerType.E_LAYER_TYPE_LAYER.name
+            tlrt.row.thickness_type = layers[i][0]
+            tlrt.row.material = layers[i][1]
+            tlrt.row.thickness = layers[i][2]
+            tlrt.row.connection_with_other_topological_elements = False
+            if Model.clientModel.service.get_material(layers[i][1])['material_model'] == "MODEL_ORTHOTROPIC_2D":
+                tlrt.row.angle = layers[i][3] * (pi/180)
+                if len(layers[i]) == 5:
+                    tlrt.row.comment = layers[i][4]
+            else:
+                if len(layers[i]) == 4:
+                    tlrt.row.comment = layers[i][3]
 
             clientObject.layers_reference_table.thickness_layers_reference_table.append(tlrt)
 
@@ -693,3 +695,15 @@ class Thickness():
 
         # Add Thickness to client model
         model.clientModel.service.set_thickness(clientObject)
+
+    @staticmethod
+    def DeleteThickness(thickness_no: str = '1 2', model = Model):
+
+        '''
+        Args:
+            thickness_no (str): Numbers of Thickness to be deleted
+        '''
+
+        # Delete from client model
+        for thickness in ConvertStrToListOfInt(thickness_no):
+            model.clientModel.service.delete_object(ObjectTypes.E_OBJECT_TYPE_THICKNESS.name, thickness)
\ No newline at end of file
