@@ -9,7 +9,8 @@ class StaticAnalysisSettings():
                  name: str = None,
                  analysis_type=StaticAnalysisType.GEOMETRICALLY_LINEAR,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
         """
         Args:
             no (int): Static Analysis Setting Tag
@@ -19,7 +20,7 @@ class StaticAnalysisSettings():
             params (dict): Parameters
         """
         # Client model | Surface
-        clientObject = Model.clientModel.factory.create('ns0:static_analysis_settings')
+        clientObject = model.clientModel.factory.create('ns0:static_analysis_settings')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -38,13 +39,15 @@ class StaticAnalysisSettings():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Static Analysis Settings to client model
-        Model.clientModel.service.set_static_analysis_settings(clientObject)
+        model.clientModel.service.set_static_analysis_settings(clientObject)
 
-    def GeometricallyLinear(self,
+    @staticmethod
+    def GeometricallyLinear(
                   no: int = 1,
                   name: str = None,
                   load_modification = [False, 1, False],
@@ -54,7 +57,8 @@ class StaticAnalysisSettings():
                   plate_bending_theory = StaticAnalysisSettingsPlateBendingTheory.PLATE_BENDING_THEORY_MINDLIN,
                   mass_conversion = [False, 0, 0, 0],
                   comment: str = '',
-                  params: dict = {}):
+                  params: dict = None,
+                  model = Model):
 
         """
         Args:
@@ -73,7 +77,7 @@ class StaticAnalysisSettings():
         """
 
         # Client model
-        clientObject = Model.clientModel.factory.create('ns0:static_analysis_settings')
+        clientObject = model.clientModel.factory.create('ns0:static_analysis_settings')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -122,13 +126,15 @@ class StaticAnalysisSettings():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Static Analysis Settings to client model
-        Model.clientModel.service.set_static_analysis_settings(clientObject)
+        model.clientModel.service.set_static_analysis_settings(clientObject)
 
-    def LargeDeformation(self,
+    @staticmethod
+    def LargeDeformation(
                   no: int = 1,
                   name: str = None,
                   iterative_method = StaticAnalysisSettingsIterativeMethodForNonlinearAnalysis.NEWTON_RAPHSON,
@@ -142,7 +148,8 @@ class StaticAnalysisSettings():
                   plate_bending_theory = StaticAnalysisSettingsPlateBendingTheory.PLATE_BENDING_THEORY_MINDLIN,
                   mass_conversion = [False, 0, 0, 1],
                   comment: str = '',
-                  params: dict = {'save_results_of_all_load_increments': False}):
+                  params: dict = {'save_results_of_all_load_increments': False},
+                  model = Model):
 
         """
         Args:
@@ -165,11 +172,11 @@ class StaticAnalysisSettings():
             mass_conversion (list, optional): Mass Conversion Parameters
                 mass_conversion = [mass_conversion_enabled, mass_conversion_factor_in_direction_x, mass_conversion_factor_in_direction_y, mass_conversion_factor_in_direction_z]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         """
 
         # Client model
-        clientObject = Model.clientModel.factory.create('ns0:static_analysis_settings')
+        clientObject = model.clientModel.factory.create('ns0:static_analysis_settings')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -243,13 +250,15 @@ class StaticAnalysisSettings():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Static Analysis Settings to client model
-        Model.clientModel.service.set_static_analysis_settings(clientObject)
+        model.clientModel.service.set_static_analysis_settings(clientObject)
 
-    def SecondOrderPDelta(self,
+    @staticmethod
+    def SecondOrderPDelta(
                   no: int = 1,
                   name: str = None,
                   iterative_method = StaticAnalysisSettingsIterativeMethodForNonlinearAnalysis.NEWTON_RAPHSON,
@@ -264,7 +273,8 @@ class StaticAnalysisSettings():
                   plate_bending_theory = StaticAnalysisSettingsPlateBendingTheory.PLATE_BENDING_THEORY_MINDLIN,
                   mass_conversion = [False, 0, 0, 1],
                   comment: str = '',
-                  params: dict = {}):
+                  params: dict = None,
+                  model = Model):
         """
         Args:
             no (int): Static Analysis Setting Tag
@@ -288,7 +298,7 @@ class StaticAnalysisSettings():
         """
 
         # Client model
-        clientObject = Model.clientModel.factory.create('ns0:static_analysis_settings')
+        clientObject = model.clientModel.factory.create('ns0:static_analysis_settings')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -361,8 +371,9 @@ class StaticAnalysisSettings():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Static Analysis Settings to client model
-        Model.clientModel.service.set_static_analysis_settings(clientObject)
+        model.clientModel.service.set_static_analysis_settings(clientObject)
