@@ -167,12 +167,12 @@ class SurfaceLoad():
 
             clientObject.varying_load_parameters = model.clientModel.factory.create('ns0:surface_load.varying_load_parameters')
             for i,j in enumerate(load_parameter):
-                mlvlp = model.clientModel.factory.create('ns0:surface_load_varying_load_parameters')
+                mlvlp = model.clientModel.factory.create('ns0:surface_load_varying_load_parameters_row')
                 mlvlp.no = i+1
-                mlvlp.distance = load_parameter[i][0]
-                mlvlp.delta_distance = load_parameter[i][1]
-                mlvlp.magnitude = load_parameter[i][2]
-                mlvlp.note = None
+                mlvlp.row.distance = load_parameter[i][0]
+                mlvlp.row.delta_distance = load_parameter[i][1]
+                mlvlp.row.magnitude = load_parameter[i][2]
+                mlvlp.row.note = None
                 clientObject.varying_load_parameters.surface_load_varying_load_parameters.append(mlvlp)
                 clientObject.varying_load_parameters_sorted = True
 
